pub struct Item<T> {
pub offset: Offset,
pub next_offset: Offset,
pub data: T,
/* private fields */
}Expand description
An item stored within the Tree whose data is stored in a pack file, identified by
the offset of its first (offset) and last (next_offset) bytes.
It represents either a root entry, or one that relies on a base to be resolvable,
alongside associated data T.
Fields
offset: OffsetThe offset into the pack file at which the pack entry’s data is located.
next_offset: OffsetThe offset of the next item in the pack file.
data: TData to store with each Item, effectively data associated with each entry in a pack.