This module is a bit ‘misplaced’ if spelled out like ‘gix_pack::cache::object::*’ but is best placed here for code reuse and
general usefulness.
Structs
- Memory
Capped Hashmap object-cache-dynamic - An LRU cache with hash map backing and an eviction rule based on the memory usage for object data in bytes.
- Never
- A cache implementation that doesn’t do any caching.