Object

Trait Object 

pub trait Object {
    // Required methods
    fn put(&mut self, id: ObjectId, kind: Kind, data: &[u8]);
    fn get(&mut self, id: &ObjectId, out: &mut Vec<u8>) -> Option<Kind>;
}
A way of storing and retrieving entire objects to and from a cache.

Required Methods

fn put(&mut self, id: ObjectId, kind: Kind, data: &[u8])

Put the object going by id of kind with data into the cache.

fn get(&mut self, id: &ObjectId, out: &mut Vec<u8>) -> Option<Kind>

Try to retrieve the object named id and place its data into out if available and return Some(kind) if found.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: Object + ?Sized> Object for Box<T>

Source

fn put(&mut self, id: ObjectId, kind: Kind, data: &[u8])

Source

fn get(&mut self, id: &ObjectId, out: &mut Vec<u8>) -> Option<Kind>

Implementors

Source

impl Object for MemoryCappedHashmap

Available on crate feature object-cache-dynamic only.
Source

impl Object for Never