pub struct Options {
pub thread_limit: Option<usize>,
pub chunk_size: usize,
pub input_object_expansion: ObjectExpansion,
}Available on crate feature
generate only.Expand description
Configuration options for the pack generation functions provided in this module.
Fields
thread_limit: Option<usize>The amount of threads to use at most when resolving the pack. If None, all logical cores are used.
If more than one thread is used, the order of returned counts is not deterministic anymore
especially when tree traversal is involved. Thus deterministic ordering requires Some(1) to be set.
chunk_size: usizeThe amount of objects per chunk or unit of work to be sent to threads for processing
input_object_expansion: ObjectExpansionThe way input objects are handled