pub struct Options<'a, 's> {
pub object_progress: Box<dyn DynNestedProgress>,
pub size_progress: &'s mut dyn Progress,
pub thread_limit: Option<usize>,
pub should_interrupt: &'a AtomicBool,
pub object_hash: Kind,
pub alloc_limit_bytes: Option<usize>,
}Expand description
Options for Tree::traverse().
Fields
object_progress: Box<dyn DynNestedProgress>is a progress instance to track progress for each object in the traversal.
size_progress: &'s mut dyn Progressis a progress instance to track the overall progress.
thread_limit: Option<usize>If Some, only use the given number of threads. Otherwise, the number of threads to use will be selected based on
the number of available logical cores.
should_interrupt: &'a AtomicBoolAbort the operation if the value is true.
object_hash: Kindspecifies what kind of hashes we expect to be stored in oid-delta entries, which is viable to decoding them with the correct size.
alloc_limit_bytes: Option<usize>If Some, rejects individual allocations above the given number of bytes while resolving decoded object and
delta result buffers. Some(0) rejects all non-empty allocations.