pub struct Outcome {
pub input_objects: usize,
pub expanded_objects: usize,
pub decoded_objects: usize,
pub total_objects: usize,
}Available on crate feature
generate only.Expand description
Information gathered during the run of iter_from_objects().
Fields
input_objects: usizeThe amount of objects provided to start the iteration.
expanded_objects: usizeThe amount of objects that have been expanded from the input source.
It’s desirable to do that as expansion happens on multiple threads, allowing the amount of input objects to be small.
expanded_objects - decoded_objects is the ‘cheap’ object we found without decoding the object itself.
decoded_objects: usizeThe amount of fully decoded objects. These are the most expensive as they are fully decoded
total_objects: usizeThe total amount of encountered objects. Should be expanded_objects + input_objects.