Entry

Struct Entry 

pub struct Entry {
    pub header: Header,
    pub decompressed_size: u64,
    pub data_offset: Offset,
}
An representing an full- or delta-object within a pack

Fields

header: Header

The entry’s header

decompressed_size: u64

The decompressed size of the entry in bytes.

Note that for non-delta entries this will be the size of the object itself.

data_offset: Offset

absolute offset to compressed object data in the pack, just behind the entry’s header

Implementations

Source

impl Entry

Decoding

pub fn from_bytes( d: &[u8], pack_offset: Offset, hash_len: usize, ) -> Result<Entry, Error>

Decode an entry from the given entry data d, providing the pack_offset to allow tracking the start of the entry data section.

Panics

If we cannot understand the header, garbage data is likely to trigger this.

pub fn from_read( r: &mut dyn Read, pack_offset: Offset, hash_len: usize, ) -> Result<Entry>

Instantiate an Entry from the reader r, providing the pack_offset to allow tracking the start of the entry data section.

Source

impl Entry

Access

pub fn checked_base_pack_offset(&self, distance: u64) -> Option<Offset>

Compute the pack offset to the base entry of the object represented by this entry, or return None if the distance would underflow or is invalid.

pub fn base_pack_offset(&self, distance: u64) -> Offset

Compute the pack offset to the base entry of the object represented by this entry.

Panics

Panics if the distance will cause an underflow or is invalid.

pub fn pack_offset(&self) -> Offset

The pack offset at which this entry starts

pub fn header_size(&self) -> usize

The amount of bytes used to describe this entry in the pack. The header starts at Self::pack_offset()